@@ -62,8 +62,8 @@ class Helper:
   def check_name(self, operation, name, names):
     ee = "Error in \"%s\" at \"name\": \n\t " % (operation)
 
-    if not isinstance(name, basestring) or re.match('^[\w]+$', name) == None:
-      msg = ee+"\"Name\" must be a non-empty STRING with only alphanumeric and underscore characters at %s. Apps and components must have names. The following methods must have names as well: \"sink\", \"inputs\" and \"outputs\"."%(str(name))
+    if not isinstance(name, basestring) or re.match('^[\w\.]+$', name) == None:
+      msg = ee+"\"Name\" must be a non-empty STRING with only alphanumeric, underscore and period characters at %s. Apps and components must have names. The following methods must have names as well: \"sink\", \"inputs\" and \"outputs\"."%(str(name))
       self.print_error(msg)
 
     # sink duplicate names are checked on their own
@@ -72,8 +72,8 @@ class Helper:
       self.print_error(msg)
     names[name] = operation
 
-    if re.match('^[0-9]$', name[0]) != None:
-      msg = ee+"The \"name\" \"%s\" cannot begin with a number."%(name)
+    if re.match('^[_0-9\.]$', name[0]) != None:
+      msg = ee+"The \"name\" \"%s\" cannot begin with a number, underscore or period."%(name)
       self.print_error(msg)
 
   @classmethod
